<?php if (!defined('APPLICATION')) exit();

$PluginInfo['LoadUp'] = array(
	'Name' => 'Load Up',
	'Description' => 'Allow users upload files (this is NOT "attachments" for Vanilla 2). Simple upload form.',
	'Version' => '1.1',
	'Date' => '5 Jun 2010',
	'Author' => 'Fox Grinder',
	'RequiredPlugins' => array('PluginUtils' => '>=1.991'),
	'RegisterPermissions' => array('Plugins.Garden.LoadUp.Allow', 'Plugins.Garden.LoadUp.Overwrite'),
	'HasLocale' => True
);

/* =======================================
CHANGELOG:
5 Jun 2010: 2.0
[*] RC related fixes

TODO:
Allow multiple uploads

CLEANUP:
1. You can remove old fields Plugins.Garden.LoadUp.* from Gdn_Permission table

======================================*/ 

class LoadUpPlugin extends Gdn_Plugin {
	
	public function Base_GetAppSettingsMenuItems_Handler(&$Sender){
		$Menu =& $Sender->EventArguments['SideMenu'];
		$Menu->AddLink('Dashboard', Gdn::Translate('Upload File'), 'dashboard/plugin/loadup', 'Plugins.Garden.LoadUp.Allow');
	}
	
	public function Setup(){
		$Config = Gdn::Factory(Gdn::AliasConfig);
		$Config->Load(PATH_CONF.DS.'config.php', 'Save');
		$Config->Set('Plugins.LoadUp.Path', 'uploads', False);
		$Config->Save();
	}
	
	public function PluginController_LoadUp_Create(&$Sender){
		
		$Sender->Permission('Plugins.Garden.LoadUp.Allow');
		if(!property_exists($Sender, 'Form')) $Sender->Form = Gdn::Factory('Form');
		
		$Sender->AddJsFile('plugins/LoadUp/loadup.js');
		$Sender->AddJsFile('plugins/LoadUp/jquery.clipboard.js');
		$Sender->AddDefinition('TextClipboarded', Gdn::Translate('saved to clipboard.'));
		
		$Session = Gdn::Session();
		
		if($Sender->Form->AuthenticatedPostBack() != False){
			
			$UploadTo = $Sender->Form->GetFormValue('UploadTo', Gdn::Config('Plugins.Garden.LoadUp.Path', 'uploads'));
			$Overwrite = $Sender->Form->GetFormValue('Overwrite') && $Session->CheckPermission('Plugins.Garden.LoadUp.Overwrite');
			$Rename = $Sender->Form->GetFormValue('Rename');
			
			try{
				$Sender->UploadedFile = self::Upload($UploadTo, 'File', $Overwrite, $Rename);
			}catch(Exception $Exception){
				$Sender->Form->AddError($Exception->GetMessage(), 'File');
			}
		}
		
		$Sender->UploadTo = $this->CollectUploadTo();

		$Sender->View = $this->GetView('loadup.php');
		$Sender->AddSideMenu('dashboard/plugin/loadup');
		$Sender->Render();
	}
	
	public static function Upload($TargetFolder, $InputName, $bOverwrite = False, $bRename = False){
		if(!$TargetFolder) $TargetFolder = C('Plugins.LoadUp.Path', 'uploads');
		
		$Files = ArrayValue('File', $_FILES);

		$Upload = new Gdn_Upload();
		$Temp = $Upload->ValidateUpload($InputName);
		
		$Name =  ArrayValue('name', ArrayValue('File', $_FILES));
		$TargetFile = GenerateCleanTargetName($TargetFolder, $Name, '', $Temp, $bOverwrite);
		
		if (file_exists($TargetFile)) {
			if ($bRename) $TargetFile = GenerateCleanTargetName($TargetFolder, $Name);
			elseif (!$bOverwrite) throw new Exception(Gdn::Translate('File exists! Rename or confirm to overwrite.'));
		}
		$Upload->SaveAs($Temp, $TargetFile);
		return $TargetFile;
	}
	
	protected function CollectUploadTo(){
		
		$UploadTo = array();
		$LoadUpPath = Gdn::Config('Plugins.Garden.LoadUp.Path', 'uploads');
		$FirstUploadDirectories = ProcessDirectory($LoadUpPath, False);
		
		foreach($FirstUploadDirectories as $Directory){
			$WritableDirectory = property_exists($Directory, 'bDirectory') && $Directory->IsWritable;
			if($WritableDirectory == False) continue;
			$NextLoadUpPath = $LoadUpPath . DS . $Directory->Filename;
			
			$UploadTo[] = $NextLoadUpPath;
			
			$SecondUploadDirectories = ProcessDirectory($NextLoadUpPath);
			foreach($SecondUploadDirectories as $Directory){
				$WritableDirectory = property_exists($Directory, 'bDirectory') && $Directory->IsWritable;
				if($WritableDirectory) $UploadTo[] = $NextLoadUpPath . DS . $Directory->Filename;
			}
		}
		if(Count($UploadTo) > 0) $UploadTo = array_combine($UploadTo, $UploadTo);
		
		return $UploadTo;
	}
	
}